doctype html html lang='en' head meta charset='utf-8' meta name='viewport' content='width=device-width, initial-scale=1, shrink-to-fit=no' meta http-equiv='x-ua-compatible' content='ie=edge' title -block name='title' -block name='extrahead' body onload='brython()' = next.body() script src='https://cdn.rawgit.com/brython-dev/brython/3.2.6/www/src/brython.js' script type='text/python' src='client.py' -block name='extrascript'